/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2014 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation;

import org.eclipse.jface.viewers.ColumnLabelProvider;
import org.eclipse.swt.graphics.Color;
import org.eclipse.wb.swt.SWTResourceManager;
import org.fortiss.tooling.base.model.element.IAnnotatedSpecification;

/**
 * This class provides the labels in the table of the annotation view when no item is selected for
 * editing.
 * 
 * @author diewald
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 8AF4DEFCE823DA131ABEFB84D93812C8
 */
public class AnnotationLabelProvider extends ColumnLabelProvider {
	/** Specification class of this column */
	protected Class<? extends IAnnotatedSpecification> specClass;

	/** Contains the basic annotation view class */
	protected AnnotationViewPartBase parentView;

	/**
	 * @param class1
	 *            specification which provides the values to be displayed
	 * 
	 * @param parent
	 *            view required to retrieve the selected elements
	 */
	public AnnotationLabelProvider(Class<? extends IAnnotatedSpecification> class1,
			AnnotationViewPartBase parent) {
		specClass = class1;
		parentView = parent;
	}

	/** {@inheritDoc} */
	@Override
	public String getText(Object element) {
		if(element instanceof AnnotationEntry) {
			AnnotationEntry data = (AnnotationEntry)element;
			return data.getSpecificationValue(specClass).toString();
		}
		return "-";
	}

	/** {@inheritDoc} */
	@Override
	public Color getBackground(Object element) {
		if(element instanceof AnnotationEntry) {
			AnnotationEntry data = (AnnotationEntry)element;
			if(data.getModelElement().equals(parentView.getCurrentlySelectedObject())) {
				return SWTResourceManager.getColor(0, 255, 0);
			}
		}
		return super.getBackground(element);
	}

}
