/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2014 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.annotation;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.viewers.ColumnViewer;
import org.eclipse.jface.viewers.EditingSupport;
import org.fortiss.tooling.base.model.element.IAnnotatedSpecification;
import org.fortiss.tooling.base.model.element.IModelElement;
import org.fortiss.tooling.kernel.service.base.IEObjectAware;

/**
 * Interface for {@link IAnnotatedSpecification}s. It defines the methods that need to be
 * implemented by a value provider to define the handling of the stored data and to retrieve
 * information relevant to the UI, like the support for complex value types.
 * 
 * @author eder, diewald
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 8BE6A1ECB76A0AD4141B7EE11CAE21DA
 */
public interface IAnnotationValueProvider<T extends IAnnotatedSpecification> extends
		IEObjectAware<IModelElement> {

	/**
	 * Returns a boolean whether the implemented specification supports storing multiple values.
	 * This method is used to handle these classes in the view part in a simpler manner.
	 */
	public boolean allowsMultipleValues();

	/** Returns the name of the Annotation for 'specification' */
	public String getAnnotationName(T specification);

	/** Sets a new name for the annotation and overrides the old one */
	public void setAnnotationName(String name, T specification) throws IllegalArgumentException;

	/** Returns the value of the annotation for 'specification' */
	public <V> V getAnnotationValue(T specification);

	/** Sets a new value for the annotation. */
	public <V> void setAnnotationValue(V value, T specification) throws IllegalArgumentException;

	/** Sets a new value in the annotation from a {@link String} representation. */
	public void setAnnotationValue(String value, T specification) throws Exception;

	/**
	 * If this method does not return null, a combo box is provided with the specific return values
	 */
	public List<String> getFixedValues();

	/**
	 * Returns a custom EditingSupport element for the annotation view
	 */
	public EditingSupport getEditElement(ColumnViewer viewer,
			Class<? extends IAnnotatedSpecification> class1, Object parent);

	/**
	 * Adds a new {@link IAnnotatedSpecification} of type T to the given model element and returns
	 * it
	 */
	public T addNewSpecToModelElement(IModelElement element);

	/** Returns the class of T */
	public Class<T> getClazz();

	/** Returns a List of Objects which children will not have {@link IAnnotatedSpecification}s */
	public List<Class<? extends EObject>> filterOut();

}
